<?php
/**
 * @file
 * ExtraWatch - Real-time visitor dashboard and stats
 * @package ExtraWatch
 * @version 4.0
 * @revision 30
 * @license http://www.gnu.org/licenses/gpl-3.0.txt     GNU General Public License v3
 * @copyright (C) 2018 by CodeGravity.com - All rights reserved!
 * @website http://www.extrawatch.com
 */

class ExtraWatchController {

    private $extraWatchCMSSpecific;
    private $extraWatchURLHelper;
    private $extraWatchRequestHelper;
    private $extraWatchRenderer;

    public function __construct(ExtraWatchCMSSpecific $extraWatchCMSSpecific) {
        $this->extraWatchCMSSpecific = $extraWatchCMSSpecific;
        $this->extraWatchURLHelper = new ExtraWatchURLHelper($extraWatchCMSSpecific);
        $this->extraWatchRequestHelper = new ExtraWatchRequestHelper($extraWatchCMSSpecific);
        $this->extraWatchRenderer = new ExtraWatchRenderer($extraWatchCMSSpecific);
        $this->extraWatchTempLogin = new ExtraWatchLogin($extraWatchCMSSpecific);
        $this->extraWatchProject = new ExtraWatchProject($extraWatchCMSSpecific);
        $this->extraWatchSettings = new ExtraWatchSettings($extraWatchCMSSpecific);
    }


    public function createAccountAndProject() {
        $createAccountStatus = $this->extraWatchTempLogin->createAccountAndLogin();
        if ($createAccountStatus) {
            $this->createProjectForURLFromSettings();
            return true;
        }
        return false;
    }

    public function controlLivePage() {

        $extraWatchPreReq = new ExtraWatchPrerequisites();
        $preReqMessage = $extraWatchPreReq->prerequisiteCheck();
        if ($preReqMessage) {
            die($preReqMessage);
        }

        if($this->extraWatchSettings->isSettingsSaveTriggered()) {
            if (!$this->extraWatchSettings->saveSettings()) {
                if ($this->extraWatchSettings->isSettingsPage()) {
                    $this->extraWatchSettings->renderExtraWatchSettings();
                } else {
                    $this->extraWatchSettings->renderExtraWatchCreateAccount();
                }
                return false;
            }
        }

        if ($this->extraWatchSettings->isSettingsPage()) {
            $this->extraWatchSettings->renderExtraWatchSettings();
            return;
        }

        if ($this->extraWatchSettings->isFromCreateAccount()) {
            $status = $this->createAccountAndProject();
            if ($status) {
                $this->extraWatchSettings->resetStoredTempPasswordAndToken();
                echo $this->extraWatchRenderer->renderAccountCreated();
                return;
            } else {
                $email = $this->extraWatchCMSSpecific->getPluginOptionEmail();
                echo("<br/><span style='color: red'>Email already registered. Either enter another email, or <a href='https://app.extrawatch.com/#/pages/reset/init?email=".htmlentities($email)."' target='_blank' style='color: red'><b>reset password</b></a>.</span>");
                $this->extraWatchSettings->renderExtraWatchCreateAccount();
                return false;
            }
        }

        if (!$this->extraWatchSettings->isInitialSettingProvided()) {
            $this->extraWatchSettings->renderExtraWatchCreateAccount();
            return;
        }


        $from = base64_encode($this->extraWatchCMSSpecific->getPluginOptionEmail());
        return $this->extraWatchRenderer->renderIFrame($from);
    }

    public function controlTrackingCode() {
        $projectId = $this->extraWatchCMSSpecific->getPluginOptionProjectId();
        if (!$projectId) {
            $projectId = $this->extraWatchTempLogin->createAccountAndLogin();
        }
        return $this->extraWatchRenderer->renderTrackingCode($projectId);
    }


    public function getExtraWatchURLHelper() {
        return $this->extraWatchURLHelper;
    }

    public function getExtraWatchRequestHelper() {
        return $this->extraWatchRequestHelper;
    }

    public function getExtraWatchRenderer() {
        return $this->extraWatchRenderer;
    }

    public function getExtraWatchTempLogin() {
        return $this->extraWatchTempLogin;
    }

    /**
     * @return array
     */
    public function createProjectForURLFromSettings() {
        $projectId = $this->extraWatchCMSSpecific->getPluginOptionProjectId();
        if (!$projectId) {
            $token = $this->extraWatchCMSSpecific->getPluginOptionToken();
            $url = $this->extraWatchCMSSpecific->getPluginOptionURL();
            $projectId = $this->extraWatchProject->createProjectForUrl($url, $token);
            $this->extraWatchCMSSpecific->savePluginOptionProjectId($projectId);
        }
        return $projectId;
    }


}