<?php
/**
 * @file
 * ExtraWatch - Real-time visitor dashboard and stats
 * @package ExtraWatch
 * @version 4.0
 * @revision 30
 * @license http://www.gnu.org/licenses/gpl-3.0.txt     GNU General Public License v3
 * @copyright (C) 2018 by CodeGravity.com - All rights reserved!
 * @website http://www.extrawatch.com
 */


class ExtraWatchRequestHelper {

    private $extraWatchCMSSpecific;
    private $extraWatchCurlHelper;


    public function __construct(ExtraWatchCMSSpecific $extraWatchCMSSpecific) {
        $this->extraWatchCMSSpecific = $extraWatchCMSSpecific;
        $this->extraWatchURLHelper = new ExtraWatchURLHelper($extraWatchCMSSpecific);
        $this->extraWatchCurlHelper = new ExtraWatchCurlHelper();
    }

    public function createProjectForUrl($url, $email, $token) {

        $postFields = array(
            "url" => $url,
            "email" => $email
        );

        $url = ExtraWatchConfig::UAA_URL."/api/projects";
        return $this->extraWatchCurlHelper->httpPostRequest($url, $postFields, $token);

    }

    public function findIfEmailExists($email) {
        $url = ExtraWatchConfig::UAA_URL."/api/users/email:".urlencode($email);
        $result = $this->extraWatchCurlHelper->httpGetRequest($url);
        return $result;
    }

    public function createNewAccount($email, $password, $generatedPassword) {
        $url = ExtraWatchConfig::UAA_URL."/api/users";
        $postFields = array("email" => $email, "password" => $password, "generatedPassword" => $generatedPassword);
        $result = $this->extraWatchCurlHelper->httpPostRequest($url, $postFields);
        if ($result) {
            return true;
        }
        return false;

    }


    public function requestLoginWithProjectIdAndTempPassword($projectId, $tempPassword) {
        $url = $this->getUrlToLoginWithTempPassword($projectId, $tempPassword);
        $content = trim($this->extraWatchURLHelper->doURLRequest($url));
        return (int) $content;

    }

    public function requestPasswordReset($email) {
        $url = ExtraWatchConfig::UAA_URL."/api/account/reset_password/init";

        $postParams = array("mail" => $email);
        return $this->extraWatchCurlHelper->httpPostRequest($url, $postParams);
    }


    private function encodeEmail($email) {
        return urlencode(base64_encode($email));
    }


}